// (C) 2019-2025 GoodData Corporation
/*
 *
 */
export { DefaultColorPalette } from "./constants/colorPalette.js";
export { BucketNames } from "./constants/bucketNames.js";
export { visualizationIsBetaWarning } from "./helpers/logging.js";
export { ErrorCodes, ForecastNotReceivedSdkError, ClusteringNotReceivedSdkError, GoodDataSdkError, UnauthorizedSdkError, NotFoundSdkError, CancelledSdkError, UnexpectedSdkError, ProtectedReportSdkError, NoDataSdkError, NegativeValuesSdkError, DataTooLargeToComputeSdkError, DataTooLargeToDisplaySdkError, GeoLocationMissingSdkError, BadRequestSdkError, GeoTokenMissingSdkError, DynamicScriptLoadSdkError, isGoodDataSdkError, isBadRequest, isCancelledSdkError, isDataTooLargeToCompute, isDataTooLargeToDisplay, isGeoLocationMissing, isGeoTokenMissing, isNegativeValues, isNoDataSdkError, isNotFound, isProtectedReport, isUnauthorized, isUnknownSdkError, isForecastNotReceived, isClusteringNotReceived, isDynamicScriptLoadSdkError, } from "./errors/GoodDataSdkError.js";
export { newErrorMapping, convertError, defaultErrorHandler } from "./errors/errorHandling.js";
export { LoadingComponent } from "./react/LoadingComponent.js";
export { ErrorComponent } from "./react/ErrorComponent.js";
export { BackendProvider, useBackend, useBackendStrict, withBackend } from "./react/BackendContext.js";
export { CorrelationProvider, useCorrelationData, useBackendWithCorrelation, BackendProviderWithCorrelation, } from "./react/CorrelationContext.js";
export { WorkspaceProvider, useWorkspace, useWorkspaceStrict, withWorkspace, } from "./react/WorkspaceContext.js";
export { PlaceholdersProvider } from "./react/placeholders/context.js";
export { isAnyPlaceholder, isPlaceholder, isComposedPlaceholder } from "./react/placeholders/base.js";
export { newComposedPlaceholder, newPlaceholder } from "./react/placeholders/factory.js";
export { usePlaceholder, usePlaceholders, useComposedPlaceholder, useResolveValueWithPlaceholders, useResolveValuesWithPlaceholders, } from "./react/placeholders/hooks.js";
export { usePagedResource } from "./react/usePagedResource.js";
export { useCancelablePromise } from "./react/useCancelablePromise.js";
export { withContexts } from "./react/withContexts.js";
export { wrapDisplayName } from "./react/wrapDisplayName.js";
export { CancelError, makeCancelable, isCancelError } from "./react/CancelablePromise.js";
export { withEntireDataView } from "./react/legacy/withEntireDataView.js";
export { getIntersectionAttributes } from "./react/legacy/availableDrillTargets.js";
export { createContextStore } from "./react/contextStore.js";
export { resolveUseCancelablePromisesError, resolveUseCancelablePromisesStatus, } from "./react/useCancelablePromiseUtils.js";
export { ClientWorkspaceProvider, ResolvedClientWorkspaceProvider, useClientWorkspaceIdentifiers, useClientWorkspaceStatus, useClientWorkspaceError, useClientWorkspaceInitialized, } from "./react/ClientWorkspaceContext/ClientWorkspaceContext.js";
export { resolveLCMWorkspaceIdentifiers } from "./react/ClientWorkspaceContext/resolveLCMWorkspaceIdentifiers.js";
export { usePrevious } from "./react/usePrevious.js";
export { usePropState } from "./react/usePropState.js";
export { useAutoupdateRef } from "./react/useAutoupdateRef.js";
export { useLocalStorage } from "./react/useLocalStorage.js";
export { DefaultLocale, isLocale, LOCALES } from "./localization/Locale.js";
export { getTranslation, getIntl } from "./localization/IntlStore.js";
export { IntlWrapper } from "./localization/IntlWrapper.js";
export { messagesMap } from "./localization/messagesMap.js";
export { TranslationsProvider, IntlTranslationsProvider } from "./localization/TranslationsProvider.js";
export { createIntlMock, withIntl, resolveLocale, emptyHeaderTitleFromIntl, totalColumnTitleFromIntl, clusterTitleFromIntl, resolveLocaleDefaultMessages, } from "./localization/intlUtils.js";
export { TranslationsCustomizationContextProvider, withTranslationsCustomization, TranslationsCustomizationProvider, pickCorrectInsightWording, pickCorrectMetricWording, pickCorrectWording, removeAllInsightToReportTranslations, removeAllWordingTranslationsWithSpecialSuffix, } from "./localization/TranslationsCustomizationProvider/index.js";
export { getMappingHeaderLocalIdentifier, hasMappingHeaderLocalIdentifier, getMappingHeaderUri, getMappingHeaderName, getMappingHeaderIdentifier, getAttributeHeaderItemName, getMappingHeaderFormattedName, hasMappingHeaderFormattedName, } from "./headerMatching/MappingHeader.js";
export { isHeaderPredicate } from "./headerMatching/HeaderPredicate.js";
export { HeaderPredicates, attributeItemNameMatch, composedFromIdentifier, composedFromUri, identifierMatch, localIdentifierMatch, uriMatch, objRefMatch, objMatch, } from "./headerMatching/HeaderPredicateFactory.js";
/*
 * Derived measure title generation
 */
export { ArithmeticMeasureTitleFactory } from "./measureTitles/ArithmeticMeasureTitleFactory.js";
export { DerivedMeasureTitleSuffixFactory } from "./measureTitles/DerivedMeasureTitleSuffixFactory.js";
export { fillMissingTitles } from "./measureTitles/fillMissingTitles.js";
export { ignoreTitlesForSimpleMeasures } from "./measureTitles/ignoreTitlesForSimpleMeasures.js";
/*
 * Derived measure format generation
 */
export { fillMissingFormats } from "./measureFormats/fillMissingFormats.js";
export { fillMissingFormat } from "./measureFormats/fillMissingFormat.js";
export { isDrillableItemIdentifier, isDrillableItemUri, isDrillableItem, isExplicitDrill, isDrillIntersectionAttributeItem, } from "./vis/DrillEvents.js";
export { convertDrillableItemsToPredicates, isSomeHeaderPredicateMatched, getDrillIntersection, getIntersectionPartAfter, fireDrillEvent, } from "./vis/drilling.js";
export { createExportFunction, createExportErrorFunction } from "./vis/export.js";
export { VisualizationTypes, getVisualizationType } from "./vis/visualizationTypes.js";
export { OverTimeComparisonTypes } from "./interfaces/OverTimeComparison.js";
/*
 *
 */
export { DataViewFacade } from "./results/facade.js";
export { createNumberJsFormatter, DefaultDataAccessConfig } from "./results/dataAccessConfig.js";
export { getTotalInfo } from "./results/internal/utils.js";
/*
 * URL utilities
 */
export { compressForUrl, decompressFromUrl } from "./url/compression.js";
//# sourceMappingURL=index.js.map